/*
Copyright (c) by respective owners including Yahoo!, Microsoft, and
individual contributors. All rights reserved.  Released under a BSD
license as described in the file LICENSE.
 */
#pragma once
const int quadratic_constant = 27942141;
const int cubic_constant = 21791;
const int cubic_constant2 = 37663;
const int affix_constant = 13903957;
const int constant = 11650396;

// FNV-like hash constant for 32bit
// http://www.isthe.com/chongo/tech/comp/fnv/#FNV-param
const uint32_t FNV_prime = 16777619;


